-- Install lazy.nvim as package manager
--    https://github.com/folke/lazy.nvim
--    https://lazy.folke.io/installation
--    `:help lazy.nvim.txt` for more info
local lazypath = vim.fn.stdpath("data") .. "/lazy/lazy.nvim"
if not (vim.uv or vim.loop).fs_stat(lazypath) then
  local lazyrepo = "https://github.com/folke/lazy.nvim.git"
  local out = vim.fn.system({
		"git",
		"clone",
		"--filter=blob:none",
		"--branch=stable",
		lazyrepo,
		lazypath
	})
  if vim.v.shell_error ~= 0 then
    vim.api.nvim_echo({
      { "Failed to clone lazy.nvim:\n", "ErrorMsg" },
      { out, "WarningMsg" },
      { "\nPress any key to exit..." },
    }, true, {})
    vim.fn.getchar()
    os.exit(1)
  end
end
vim.opt.rtp:prepend(lazypath)

-- Add the site folder of .local/share/nvim/ in the runtime path
-- which is rewritten by lazy.nvim.
--  https://github.com/neovim/neovim/issues/23082#issuecomment-1510812311
vim.opt.rtp:append (vim.fn.stdpath ('data') .. '/site')

-- Configure lazy.nvim
require("lazy").setup({
	spec = {
		-- Import the plugins directory and subdirectories
		{ import = "plugins" },
    -- Markdown related plugings and configuration
		{ import = "plugins.markdown" },
    -- LSP related plugins and configuration
		{ import = "plugins.lsp" },
	},
	-- Automatically check for plugin updates
  checker = {
    enabled = true,
    notify = false
  },
  -- Theme during installation
  install = {
    colorscheme = {
      "adwaita"
    }
  },
})
